@@ -1,5 +1,6 @@
 #' @include zzz.R
 #' @include generics.R
+#' @include graph.R
 #' @importFrom methods new slot slot<-
 #'
 NULL
@@ -8,6 +9,8 @@ NULL
 # Class definitions
 #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
+setClassUnion(name = 'AnyMatrix', members = c("matrix", "dgCMatrix"))
+
 #' The Assay Class
 #'
 #' The Assay object is the basic unit of Seurat; each Assay stores raw,
@@ -1205,7 +1208,7 @@ ValidateDataForMerge <- function(assay, slot) {
       ncol = data.dims[2],
       dimnames = dimnames(x = GetAssayData(object = assay, slot = data.slot))
     )
-    mat <- as(object = mat, Class = "dgCMatrix")
+    mat <- as.sparse(x = mat)
   }
   return(mat)
 }
